Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(504)

Unified Diff: ui/views/widget/desktop_aura/x11_topmost_window_finder.h

Issue 1003863005: Fix tab drag and drop with hi-dpi. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix tab drag and drop with hi-dpi. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/widget/desktop_aura/x11_topmost_window_finder.h
diff --git a/ui/views/widget/desktop_aura/x11_topmost_window_finder.h b/ui/views/widget/desktop_aura/x11_topmost_window_finder.h
index 4f26efc3048a56bfc5d4d944511aab54161ae47d..5e3567a75283df63acd21ddfd4c70f2aa6f40e4e 100644
--- a/ui/views/widget/desktop_aura/x11_topmost_window_finder.h
+++ b/ui/views/widget/desktop_aura/x11_topmost_window_finder.h
@@ -24,14 +24,14 @@ class VIEWS_EXPORT X11TopmostWindowFinder
X11TopmostWindowFinder();
~X11TopmostWindowFinder() override;
- // Returns the topmost window at |screen_loc|, ignoring the windows in
- // |ignore|. Returns NULL if the topmost window at |screen_loc| does not
- // belong to Chrome.
- aura::Window* FindLocalProcessWindowAt(const gfx::Point& screen_loc,
+ // Returns the topmost window at |screen_loc_in_pixels|, ignoring the windows
+ // in |ignore|. Returns NULL if the topmost window at |screen_loc_in_pixels|
+ // does not belong to Chrome.
+ aura::Window* FindLocalProcessWindowAt(const gfx::Point& screen_loc_in_pixels,
const std::set<aura::Window*>& ignore);
- // Returns the topmost window at |screen_loc|.
- XID FindWindowAt(const gfx::Point& screen_loc);
+ // Returns the topmost window at |screen_loc_in_pixels|.
+ XID FindWindowAt(const gfx::Point& screen_loc_in_pixels);
private:
// ui::EnumerateWindowsDelegate:
@@ -41,7 +41,7 @@ class VIEWS_EXPORT X11TopmostWindowFinder
// contains |screen_loc_|.
bool ShouldStopIteratingAtLocalProcessWindow(aura::Window* window);
- gfx::Point screen_loc_;
+ gfx::Point screen_loc_in_pixels_;
std::set<aura::Window*> ignore_;
XID toplevel_;
« no previous file with comments | « ui/views/widget/desktop_aura/desktop_screen_x11.cc ('k') | ui/views/widget/desktop_aura/x11_topmost_window_finder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698